function  varargout=demo(varargin)
  formats=fc_oogmsh.gmsh.getMSHfile_formats();
  p = inputParser;
  p.addParamValue('geofile','condenser',@ischar);
  p.addParamValue('MshFileVersion','4.1',@(x) ismember(x,formats));
  p.addParamValue('N',4,@isscalar);
  p.addParamValue('d',2,@isscalar);
  p.addParamValue('np',1,@isscalar); % number of partition 
  p.parse(varargin{:});
  R=p.Results;
  linesep=fc_tools.utils.line_text_delimiter();
  fprintf(linesep)
  fprintf('  1st step: GEO file -> MSH file \n')
  fprintf('  2nd step: MSH file -> MSH partitioned file \n')
  fprintf(linesep)

  fprintf('1. Building a mesh file by using :\n')
  fprintf('   -> gmsh version %s\n',fc_oogmsh.gmsh.version())
  fprintf('   -> geo file : %s\n',R.geofile);
  fprintf('   -> mesh file format : %s\n',R.MshFileVersion);
  meshfile=fc_oogmsh.gmsh.buildmesh(R.geofile,R.N,'d',R.d,'verbose',1,'force',true,'MshFileVersion',R.MshFileVersion);
  fprintf('   -> msh file : %s\n',fc_oogmsh.pathrep(meshfile));
  fprintf('2. Reading mesh file\n')
  if strcmp(R.MshFileVersion,'2.2')
    Gh=fc_oogmsh.ooGmsh2(meshfile);
  else
    Gh=fc_oogmsh.ooGmsh4(meshfile);
  end
  fprintf('   -> Mesh file format: %s\n',Gh.MeshFormat.version);
  if R.np==1
    pGh=[];
    num=3;
  else
    fprintf('3. Building partitioned mesh file\n')
    fprintf('   -> number of partitions : %d\n',R.np);
    pmfile=fc_oogmsh.gmsh.buildpartmesh(meshfile,R.np,'verbose',1,'force',true,'MshFileVersion',R.MshFileVersion);
    fprintf('   -> partitioned msh file : %s\n',fc_oogmsh.pathrep(pmfile));
    fprintf('4. Reading the partitioned mesh file\n')
    if strcmp(R.MshFileVersion,'2.2')
      pGh=fc_oogmsh.ooGmsh2(pmfile);
    else
      pGh=fc_oogmsh.ooGmsh4(pmfile);
    end
    fprintf('   -> Mesh file format: %s\n',pGh.MeshFormat.version);
    num=5;
  end
  fprintf(linesep)
  if nargout==1,varargout{1}=Gh;end
end
