function plot_PhysicalTags(Gh)
  assert( ~Gh.partitionnedfile ,' Not yet implemented for partionned files ' )
  isooGmsh2=ismember(class(Gh),{'fc_oogmsh.ooGmsh2','ooGmsh2'});
  LegendOptions={'Location','NorthEastOutside','AutoUpdate','off'};
  [Soft,Release]=fc_tools.sys.getSoftware();
  if strcmp(lower(Soft),'octave') &&  ( fc_tools.utils.strversion2num(Release) <=  fc_tools.utils.strversion2num('4.2.1') )
    LegendOptions={'Location','NorthEastOutside'};
  elseif strcmp(lower(Soft),'matlab') &&  verLessThan('matlab','R2016b')
    LegendOptions={'Location','NorthEastOutside'};
  end
  
  type=1; % line
  elt=fc_oogmsh.gmsh.elm_type_desc(type);
  desc1=elt.desc;
  
  phtags1=Gh.get_PhysicalTags(type);q1={};me1={};
  n1=length(phtags1);
  fprintf('  %s :\n',desc1)
  k=1;
  for i=1:n1
    [Q,ME]=Gh.get_localmesh_PhysicalTag(type,phtags1(i));
    if ~isempty(ME)
      q1{k}=Q;me1{k}=ME;
      fprintf('     physical_tag=%7d, nq=%7d, nme=%7d\n',phtags1(i),size(q1{k},2),size(me1{k},2))
      k=k+1;
    else
      fprintf('     physical_tag=%7d, nq=%7d, nme=%7d -> DELETED\n',phtags1(i),size(Q,2),size(ME,2))
    end
  end
  n1=length(q1);

  type=2; % triangle
  elt=fc_oogmsh.gmsh.elm_type_desc(type);
  desc2=elt.desc;
  
  
  phtags2=Gh.get_PhysicalTags(type);q2={};me2={};
  n2=length(phtags2);
  fprintf('  %s :\n',desc2)
  k=1;
  for i=1:n2
    [Q,ME]=Gh.get_localmesh_PhysicalTag(type,phtags2(i));
    if ~isempty(ME)
      q2{k}=Q;me2{k}=ME;
      fprintf('     physical_tag=%7d, nq=%7d, nme=%7d\n',phtags2(i),size(q2{k},2),size(me2{k},2))
      k=k+1;
    else
      fprintf('     physical_tag=%7d, nq=%7d, nme=%7d -> DELETED\n',phtags2(i),size(Q,2),size(ME,2))
    end
  end
  n2=length(q2);

  if Gh.dim==3
    type=4; % tetrahedron
    elt=fc_oogmsh.gmsh.elm_type_desc(type);
    desc3=elt.desc;
    
    phtags3=Gh.get_PhysicalTags(type);q3={};me3={};
    n3=length(phtags3);
    fprintf('  %s :\n',desc3)
    k=1;
    for i=1:n3
      [Q,ME]=Gh.get_localmesh_PhysicalTag(type,phtags3(i));
      if ~isempty(ME) 
        q3{k}=Q;me3{k}=ME;
        fprintf('     physical_tag=%7d, nq=%7d, nme=%7d\n',phtags3(i),size(q3{k},2),size(me3{k},2))
        k=k+1;
      else
        fprintf('     physical_tag=%7d, nq=%7d, nme=%7d -> DELETED\n',phtags3(i),size(Q,2),size(ME,2))
      end
    end
    n3=length(q3);
  else
    n3=0;
  end

  if n1>0
    figure()
    colors = fc_tools.graphics.selectColors(n1);
    hold on
    labname=fc_oogmsh.funLabName(Gh.dim,1);
    for i=1:n1
      h1(i)=fc_graphics4mesh.plotmesh(q1{i},me1{i},'color',colors(i,:));
      clegend1{i}=labname(phtags1(i));
    end
    if Gh.dim==3,view(3);end
    legend(h1,clegend1,LegendOptions{:});
    axis image
    title(sprintf('Physical Tags for %s',desc1))
  end
  
  if n2>0
    figure()
    colors = fc_tools.graphics.selectColors(n2);
    hold on
    labname=fc_oogmsh.funLabName(Gh.dim,2);
    for i=1:n2
      h2(i)=fc_graphics4mesh.plotmesh(q2{i},me2{i},'color',colors(i,:));
      clegend2{i}=labname(phtags2(i));
    end
    if Gh.dim==3,view(3);end
    legend(h2,clegend2,LegendOptions{:}); 
    axis image
    title(sprintf('Physical Tags for %s',desc2))
  end
  
  if n3>0
    figure()
    colors = fc_tools.graphics.selectColors(n3);
    hold on
    labname=fc_oogmsh.funLabName(Gh.dim,3);
    for i=1:n3
      h3(i)=fc_graphics4mesh.plotmesh(q3{i},me3{i},'color',colors(i,:));
      clegend3{i}=labname(phtags3(i));
    end
    view(3)
    legend(h3,clegend3,LegendOptions{:}); 
    axis image
    title(sprintf('Physical Tags for %s',desc3))
  end
 end 
